/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.factories;

import biz.massivedynamics.aurora.runescape.network.netty.handlers.ServiceServerHandler;
import biz.massivedynamics.aurora.runescape.network.netty.service.ServiceRequestDecoder;
import biz.massivedynamics.aurora.runescape.network.netty.service.ServiceResponseEncoder;
import org.jboss.netty.channel.ChannelPipeline;
import org.jboss.netty.channel.ChannelPipelineFactory;
import org.jboss.netty.channel.Channels;

/**
 * The pipeline factory for the main game (packets and ondemand)
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class GamePipelineFactory implements ChannelPipelineFactory {

    /**
     * Gets the pipeline
     * 
     * @return The pipeline
     * @throws Exception Any exceptions that occur
     * @since 1.0.0.0
     */
    @Override
    public ChannelPipeline getPipeline() throws Exception {
        //Get a pipeline
        ChannelPipeline pipeline = Channels.pipeline();
        
        pipeline.addLast("decoder", new ServiceRequestDecoder());
        
        pipeline.addLast("encoder", new ServiceResponseEncoder());
        
        pipeline.addLast("handler", new ServiceServerHandler());
        
        //And return it
        return pipeline;
    }
    
}
