/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.factories;

import biz.massivedynamics.aurora.runescape.network.netty.handlers.UpdateServerHandler;
import org.jboss.netty.channel.ChannelPipeline;
import org.jboss.netty.channel.ChannelPipelineFactory;
import org.jboss.netty.channel.Channels;
import org.jboss.netty.handler.codec.http.HttpChunkAggregator;
import org.jboss.netty.handler.codec.http.HttpRequestDecoder;
import org.jboss.netty.handler.codec.http.HttpResponseEncoder;

/**
 * The HTTP pipeline factory
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class HTTPPipelineFactory implements ChannelPipelineFactory {

    /**
     * Gets the channel pipeline
     * 
     * @return The channel pipeline
     * @throws Exception Something went wrong
     */
    public ChannelPipeline getPipeline() throws Exception {
        //Get a generic pipeline
        ChannelPipeline pipeline = Channels.pipeline();

        //Set the decoder
        pipeline.addLast("decoder", new HttpRequestDecoder());
        //And the chunker
        pipeline.addLast("chunker", new HttpChunkAggregator(8192));

        //Set the encoder
        pipeline.addLast("encoder", new HttpResponseEncoder());
        
        //And the handler
        pipeline.addLast("handler", new UpdateServerHandler());
        
        return pipeline;
    }
    
}
