/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.factories;

import biz.massivedynamics.aurora.runescape.network.netty.handlers.UpdateServerHandler;
import biz.massivedynamics.aurora.runescape.network.netty.updateserver.jaggrab.JagGrabRequestDecoder;
import biz.massivedynamics.aurora.runescape.network.netty.updateserver.jaggrab.JagGrabResponseEncoder;
import java.nio.charset.Charset;
import org.jboss.netty.buffer.ChannelBuffer;
import org.jboss.netty.buffer.ChannelBuffers;
import org.jboss.netty.channel.ChannelPipeline;
import org.jboss.netty.channel.ChannelPipelineFactory;
import org.jboss.netty.channel.Channels;
import org.jboss.netty.handler.codec.frame.DelimiterBasedFrameDecoder;
import org.jboss.netty.handler.codec.string.StringDecoder;

/**
 * A pipeline factory for JagGrab requests
 *
 * @author Cruz Bishop
 * @author Graham Edgecombe
 * @version 0.1.0.0
 */
public class JagGrabPipelineFactory implements ChannelPipelineFactory {
    
    /**
     * A buffer with two line feed (LF) characters in it.
     * 
     * @author Graham Edgecombe
     * @since 0.1.0.0
     */
    private static final ChannelBuffer DOUBLE_LINE_FEED_DELIMITER = ChannelBuffers.buffer(2);

    /**
     * Populates the double line feed buffer.
     * 
     * @author Graham Edgecombe
     * @since 0.1.0.0
     */
    static {
        DOUBLE_LINE_FEED_DELIMITER.writeByte(10);
        DOUBLE_LINE_FEED_DELIMITER.writeByte(10);
    }

    /**
     * Gets the channel pipeline
     * 
     * @return The channel pipeline
     * @throws Exception Any exceptions that are thrown
     * @since 0.1.0.0
     */
    public ChannelPipeline getPipeline() throws Exception {
        //Set up a new channel pipeline
        ChannelPipeline pipeline = Channels.pipeline();
        
        //Set up a framer
        pipeline.addLast("framer", new DelimiterBasedFrameDecoder(8192, DOUBLE_LINE_FEED_DELIMITER));
        //And a string decoder
        pipeline.addLast("string-decoder", new StringDecoder(Charset.forName("US-ASCII")));
        //And a jaggrab request decoder
        pipeline.addLast("jaggrab-decoder", new JagGrabRequestDecoder());
        
        //Add a jaggrab request encoder
        pipeline.addLast("jaggrab-encoder", new JagGrabResponseEncoder());
        
        //Finally, add the handler
        pipeline.addLast("handler", new UpdateServerHandler());
        
        //And return
        return pipeline;
    }
    
}
