/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.handlers;

import biz.massivedynamics.aurora.runescape.network.netty.service.ServiceRequest;
import biz.massivedynamics.aurora.runescape.network.netty.service.ServiceResponse;
import biz.massivedynamics.modger.Logger;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.channel.MessageEvent;
import org.jboss.netty.channel.SimpleChannelUpstreamHandler;

/**
 * A service server handler
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class ServiceServerHandler extends SimpleChannelUpstreamHandler {
    
    /**
     * The logger for this class
     * 
     * @since 1.0.0.0
     */
    private Logger logger = new Logger("Service Server");

    /**
     * Called when a message is received
     * 
     * @param ctx The channel handler context
     * @param e The message event
     * @throws Exception Any exceptions
     * @since 1.0.0.0
     */
    @Override
    public void messageReceived(ChannelHandlerContext ctx, MessageEvent e) throws Exception {
        if (e.getMessage() instanceof ServiceRequest) {
            ServiceRequest request = (ServiceRequest) e.getMessage();
            
            logger.submitInformation("SERVICE " + request.getId());
            
            if (request.getId() == ServiceRequest.SERVICE_GAME) {
                e.getChannel().close(); //TODO Game packet decoding
            } else {
                
            }
            
            e.getChannel().write(new ServiceResponse());
        } else throw new Exception("Unknown message: " + e.getMessage().getClass().getName());
    }
    
}
