/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.service;

import org.jboss.netty.buffer.ChannelBuffer;
import org.jboss.netty.buffer.ChannelBuffers;
import org.jboss.netty.channel.Channel;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.handler.codec.oneone.OneToOneEncoder;

/**
 * Encodes service responses
 *
 * @author Cruz Bishop
 * @author Graham Edgecombe
 * @version 1.0.0.0
 */
public class ServiceResponseEncoder extends OneToOneEncoder {

    /**
     * Encodes the service response
     * 
     * @param context The channel handler context
     * @param channel The channel
     * @param data The data to send/encode
     * @return The encoded data
     * @throws Exception Any exceptions
     * @since 1.0.0.0
     */
    @Override
    protected Object encode(ChannelHandlerContext context, Channel channel, Object data) throws Exception {
        //See if we're writing a service response
        if (data instanceof ServiceResponse) {
            //Remove the current encoder
            context.getPipeline().remove(this);
            //Get a channel buffer
            ChannelBuffer buffer = ChannelBuffers.buffer(8);
            
            //Write a long
            buffer.writeLong(0);
            //Return the buffer
            return buffer;
        }
        //Return the data
        return data;
    }
    
}
