/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.updateserver;

import biz.massivedynamics.aurora.runescape.Server;
import java.io.IOException;
import java.nio.ByteBuffer;

/**
 * Utility methods for handling update server requests
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class RequestHandler {
    
    /**
     * Gets the data associated with a request path
     * 
     * @param path The path
     * @return The data, or null if not found
     * @throws IOException Any I/O exceptions
     */
    public static ByteBuffer get(String path) throws IOException {
        if (path.startsWith("/crc")) {
            return Server.getInstance().getCache().getCRCTable();
        } else if (path.startsWith("/title")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(1).getData();
        } else if (path.startsWith("/config")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(2).getData();
        } else if (path.startsWith("/interface")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(3).getData();
        } else if (path.startsWith("/media")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(4).getData();
        } else if (path.startsWith("/versionlist")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(5).getData();
        } else if (path.startsWith("/textures")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(6).getData();
        } else if (path.startsWith("/wordenc")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(7).getData();
        } else if (path.startsWith("/sounds")) {
            return Server.getInstance().getCache().getIndexFile(0).getVirtualFileIndex(8).getData();
        } else return null;
    }
    
}
