/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.runescape.network.netty.updateserver.jaggrab;

import org.jboss.netty.channel.Channel;
import org.jboss.netty.channel.ChannelHandlerContext;
import org.jboss.netty.handler.codec.oneone.OneToOneDecoder;

/**
 * A decoder for JagGrab requests
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class JagGrabRequestDecoder extends OneToOneDecoder {

    /**
     * Decodes the incoming request
     * 
     * @param context The channel handler context
     * @param channel The channel
     * @param message The message
     * @return The decoded request
     * @throws Exception Something went wrong
     */
    @Override
    protected Object decode(ChannelHandlerContext context, Channel channel, Object message) throws Exception {
        //See if the message is a string
        if (message instanceof String) {
            String string = (String) message;
            //See if it's a JagGrab request
            if (string.startsWith("JAGGRAB /")) {
                //It is, return a new request
                return new JagGrabRequest(string.substring(8).trim());
            } else {
                throw new Exception("Invalid or unimplemented JAGGRAB request");
            }
        }
        //Okay, it's not a string. Just return it.
        return message;
    }
    
}
