/*
 * The MIT License
 *
 * Copyright 2012 Massive Dynamics.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package biz.massivedynamics.aurora.sourcery.managers.generic;

import biz.massivedynamics.sourcery.management.settings.YamlSettingsResourceManager;
import biz.massivedynamics.sourcery.resource.impl.Settings;
import java.io.File;

/**
 * The settings resource manager
 *
 * @author Cruz Bishop
 * @version 1.0.0.0
 */
public class SettingsResourceManager extends YamlSettingsResourceManager {

    /**
     * Creates a new settings resource manager
     * 
     * @since 1.0.0.0
     */
    public SettingsResourceManager() {
        super(new File("Data/Settings.yml"));
    }
    
    /**
     * Gets the default settings
     * 
     * @return The default settings
     * @since 1.0.0.0
     */
    @Override
    public Settings getDefault() {
        //Set up some new settings
        Settings settings = new Settings();
        
        //Add some settings
        settings.addSetting("serverName", "Aurora");
        
        settings.addSetting("loginMessages", new String[] {
            "Welcome to Aurora!",
            "Please break everything you can and report bugs!"
        });
        
        settings.addSetting("gamePort", 43594);
        
        settings.addSetting("httpPort", 80);
        
        settings.addSetting("jaggrabPort", 43595);
        
        //Return the settings
        return settings;
    }

    
    
}
